==> org.eclipse.riena.ui.swt.rap.source_3.0.0.v20110614_3_0_0_0.jar: org/eclipse/riena/ui/swt/facades/internal/AbstractCompletionComboRAP.java <==
/*******************************************************************************
 * Copyright (c) 2000, 2010 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation (CCombo)
 *     compeople AG    - adjustments for autocompletion
 *******************************************************************************/
package org.eclipse.riena.ui.swt.facades.internal;

import org.eclipse.swt.events.ModifyEvent;
import org.eclipse.swt.events.ModifyListener;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.events.SelectionListener;
import org.eclipse.swt.events.VerifyEvent;
import org.eclipse.swt.events.VerifyListener;
import org.eclipse.swt.widgets.Composite;

import org.eclipse.riena.ui.swt.CompletionCombo;

/**
 * RAP specific implementation of a {@link CompletionCombo}. There are two
 * concrete subclasses:
 * <ul>
 * <li>CompletionComboRAP &ndash; a CompletionCombo with a text field and a list
 * widget</li>
 * <li>CompletionComboWithImageRAP &ndash; a CompletionCombo with a text field,
 * with an optional image on the left, and a table widget (which can show an
 * image next to each item)</li>
 * </ul>
 */
abstract class AbstractCompletionComboRAP extends CompletionCombo {

	protected AbstractCompletionComboRAP(final Composite parent, final int style) {
		super(parent, style);
	}

	@Override
	public void addModifyListener(final ModifyListener listener) {
		checkWidget();
		ModifyEvent.addListener(this, listener);
	}

	@Override
	public void addSelectionListener(final SelectionListener listener) {
		checkWidget();
		SelectionEvent.addListener(this, listener);
	}

	@Override
	public void addVerifyListener(final VerifyListener listener) {
		checkWidget();
		VerifyEvent.addListener(this, listener);
	}

	@Override
	public void removeModifyListener(final ModifyListener listener) {
		checkWidget();
		ModifyEvent.removeListener(this, listener);
	}

	@Override
	public void removeSelectionListener(final SelectionListener listener) {
		checkWidget();
		SelectionEvent.removeListener(this, listener);
	}

	@Override
	public void removeVerifyListener(final VerifyListener listener) {
		checkWidget();
		VerifyEvent.addListener(this, listener);
	}

}

==> org.eclipse.riena.ui.swt.rap.source_5.0.0.v20130605_5_0_0_0.jar: org/eclipse/riena/ui/swt/facades/internal/AbstractCompletionComboRAP.java <==
/*******************************************************************************
 * Copyright (c) 2000, 2010 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation (CCombo)
 *     compeople AG    - adjustments for autocompletion
 *******************************************************************************/
package org.eclipse.riena.ui.swt.facades.internal;

import org.eclipse.swt.SWT;
import org.eclipse.swt.events.ModifyListener;
import org.eclipse.swt.events.SelectionListener;
import org.eclipse.swt.events.VerifyListener;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.TypedListener;

import org.eclipse.riena.ui.swt.CompletionCombo;

/**
 * RAP specific implementation of a {@link CompletionCombo}. There are two
 * concrete subclasses:
 * <ul>
 * <li>CompletionComboRAP &ndash; a CompletionCombo with a text field and a list
 * widget</li>
 * <li>CompletionComboWithImageRAP &ndash; a CompletionCombo with a text field,
 * with an optional image on the left, and a table widget (which can show an
 * image next to each item)</li>
 * </ul>
 */
abstract class AbstractCompletionComboRAP extends CompletionCombo {

	protected AbstractCompletionComboRAP(final Composite parent, final int style) {
		super(parent, style);
	}

	@Override
	public void addModifyListener(final ModifyListener listener) {
		checkWidget();
		//		ModifyEvent.addListener(this, listener);
		final TypedListener typedListener = new TypedListener(listener);
		addListener(SWT.Modify, typedListener);
	}

	@Override
	public void addSelectionListener(final SelectionListener listener) {
		checkWidget();
		//		SelectionEvent.addListener(this, listener);
		final TypedListener typedListener = new TypedListener(listener);
		addListener(SWT.Selection, typedListener);
		addListener(SWT.DefaultSelection, typedListener);
	}

	@Override
	public void addVerifyListener(final VerifyListener listener) {
		checkWidget();
		//		VerifyEvent.addListener(this, listener);
		final TypedListener typedListener = new TypedListener(listener);
		addListener(SWT.Verify, typedListener);
	}

	@Override
	public void removeModifyListener(final ModifyListener listener) {
		checkWidget();
		//		ModifyEvent.removeListener(this, listener);
		removeListener(SWT.Modify, listener);
	}

	@Override
	public void removeSelectionListener(final SelectionListener listener) {
		checkWidget();
		//		SelectionEvent.removeListener(this, listener);
		removeListener(SWT.Selection, listener);
		removeListener(SWT.DefaultSelection, listener);
	}

	@Override
	public void removeVerifyListener(final VerifyListener listener) {
		checkWidget();
		//		VerifyEvent.addListener(this, listener);
		removeListener(SWT.Verify, listener);
	}

}
